//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[YakuSerializer](index.md)/[serialize](serialize.md)

# serialize

[common]\
open override fun [serialize](serialize.md)(encoder: Encoder, value: [Yaku](../-yaku/index.md))
